@@ -12,8 +12,6 @@
 #include <QStandardPaths>
 #include <QTest>
 
-#include <KPixmapSequence>
-
 #include <KConfigGroup>
 #include <KSharedConfig>
 
@@ -33,7 +31,7 @@ private:
     QDir testIconsDir;
     QString appName;
     QDir appDataDir;
-    const QVector<int> testSizes;
+    const QList<int> testSizes;
 
 private Q_SLOTS:
     void initTestCase()
@@ -458,12 +456,6 @@ private Q_SLOTS:
         QCOMPARE(pix.cacheKey(), pix2.cacheKey());
     }
 
-    void testLoadPixmapSequence()
-    {
-        KPixmapSequence seq = KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22);
-        QVERIFY(seq.isValid());
-    }
-
     void testAppropriateSizes()
     {
         const KIconLoader iconLoader;
