@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KICONENGINE_H
@@ -23,7 +12,9 @@
 #include <QIconEngine>
 #include <QPointer>
 
+class KIconColors;
 class KIconLoader;
+class KIconEnginePrivate;
 
 /**
  * @class KIconEngine kiconengine.h KIconEngine
@@ -59,6 +50,15 @@ public:
      */
     KIconEngine(const QString &iconName, KIconLoader *iconLoader);
 
+    /**
+     * Constructs an icon engine for a KDE named icon with a specific palette.
+     *
+     * @param iconName the name of the icon to load
+     * @param colors defines the colors we want to be applied on this icon
+     * @param iconLoader The KDE icon loader that this engine is to use.
+     */
+    KIconEngine(const QString &iconName, const KIconColors &colors, KIconLoader *iconLoader);
+
     /**
      * Destructor.
      */
@@ -70,28 +70,26 @@ public:
     void paint(QPainter *painter, const QRect &rect, QIcon::Mode mode, QIcon::State state) override;
     /// Reimplementation
     QPixmap pixmap(const QSize &size, QIcon::Mode mode, QIcon::State state) override;
+    QPixmap scaledPixmap(const QSize &size, QIcon::Mode mode, QIcon::State state, qreal scale) override;
+
     /// Reimplementation
-    QString iconName() const override;
+    QString iconName() override;
     /// Reimplementation
-    QList<QSize> availableSizes(QIcon::Mode mode, QIcon::State state) const override;
+    QList<QSize> availableSizes(QIcon::Mode mode, QIcon::State state) override;
+
+    bool isNull() override;
 
     QString key() const override;
     QIconEngine *clone() const override;
     bool read(QDataStream &in) override;
     bool write(QDataStream &out) const override;
 
-    void virtual_hook(int id, void *data) override;
-
 private:
-    //TODO KF6: move those into the d-pointer
+    // TODO KF6: move those into the d-pointer
     QPixmap createPixmap(const QSize &size, qreal scale, QIcon::Mode mode, QIcon::State state);
     QString mIconName;
     QStringList mOverlays;
-    QPointer<KIconLoader> mIconLoader;
+    KIconEnginePrivate *const d;
 };
 
-inline KIconEngine::~KIconEngine()
-{
-}
-
 #endif
